# FileName: dataTransformer.py
# Name: Danielle Perszyk
# This script grabs all of the counties in wisco-counties.txt and then gets
# hour-by-hour data for the year 2015 for all Wisconsin counties.

from forecastiopy import *
from pymongo import MongoClient
import datetime


apikey = YOUR_DARK_SKY_API_KEY_HERE
client = MongoClient('localhost', 27017)

county_idx = 0
for line in open('C:/Users/Danielle/Desktop/wisco-counties.txt','r').readlines():
    county_info = line.split(",")
    county_idx += 1
    county_coords = [county_info[2], county_info[3]]  # County Coordinates needed for Dark Sky API call
    county_id = county_info[0]
    county_name = county_info[1]

    date = datetime.datetime(2015,1,1,0,0,0,0)  # Starts at January 1, 2015 at midnight
	# Python datetime stuff: http://stackoverflow.com/questions/311627/how-to-print-date-in-a-regular-format-in-python
    for i in range(365):
        t = (date.strftime('%Y-%m-%dT%H:%M:%S'))
        print(county_idx, t)

        already_there = False
        if county_name in client.counties.collection_names():
            already_there = client.counties[county_name].count({"day_of_year":i}) > 0

        if already_there:
            print("Skipped! Already there...")
            date += datetime.timedelta(days=1)
            continue

        # Make the API call
		# For this library's documentation, visit: https://github.com/dvdme/forecastiopy
        fio = ForecastIO.ForecastIO(apikey,
                                    lang=ForecastIO.ForecastIO.LANG_ENGLISH,
                                    latitude=county_coords[0], longitude=county_coords[1],
                                    time=t)

        # Save the data from the API Call
        if fio.has_hourly() is True:
            hourly = FIOHourly.FIOHourly(fio)
            entry = {}

            entry['accessed_date'] = datetime.datetime.now()
            entry['query_date'] = date
            entry['summary'] = hourly.summary
            entry['icon'] = hourly.icon
            entry['latitude'] = fio.latitude
            entry['day_of_year'] = i
            entry['longitude'] = fio.longitude
            entry['timezone'] = fio.timezone
            entry['offset'] = fio.offset
            entry['county_name'] = county_name
            entry['county_id'] = county_id
            entry['hours'] = []

            for hour in range(0, hourly.hours()): # should be 24 hours
            #    print('Hour', hour + 1)
                hour_entry = {}

                for item in hourly.get_hour(hour).keys():
                    hour_entry[item] = hourly.get_hour(hour)[item]  # this holds information such as cloud-cover, windspeed, temp, etc.

                entry['hours'].append(hour_entry)

            client.counties[county_name].insert_one(entry)  # add a document for the day/hour combo to the database under that county's collection name

        else:
            print('No Hourly data')

        date += datetime.timedelta(days=1)  # increment the day number
